@@ -1,10 +1,14 @@
     ".academy",
     ".accountants",
+    ".active",
     ".actor",
     ".agency",
     ".airforce",
     ".archi",
+    ".army",
     ".associates",
+    ".attorney",
+    ".auction",
     ".audio",
     ".autos",
     ".axa",
@@ -16,16 +20,22 @@
     ".best",
     ".bid",
     ".bike",
+    ".bio",
     ".black",
     ".blackfriday",
     ".blue",
+    ".bmw",
     ".boutique",
+    ".brussels",
     ".build",
     ".builders",
     ".buzz",
+    ".bzh",
     ".cab",
     ".camera",
     ".camp",
+    ".cancerresearch",
+    ".capetown",
     ".capital",
     ".cards",
     ".care",
@@ -39,6 +49,7 @@
     ".christmas",
     ".church",
     ".citic",
+    ".city",
     ".claims",
     ".cleaning",
     ".clinic",
@@ -62,19 +73,26 @@
     ".credit",
     ".creditcard",
     ".cruises",
+    ".cuisinella",
     ".dance",
     ".dating",
+    ".deals",
+    ".degree",
     ".democrat",
     ".dental",
+    ".dentist",
     ".desi",
     ".diamonds",
     ".digital",
+    ".direct",
     ".directory",
     ".discount",
     ".dnp",
     ".domains",
+    ".durban",
     ".education",
     ".email",
+    ".engineer",
     ".engineering",
     ".enterprises",
     ".equipment",
@@ -102,23 +120,30 @@
     ".futbol",
     ".gal",
     ".gallery",
+    ".gent",
     ".gift",
+    ".gives",
     ".glass",
+    ".global",
     ".globo",
     ".gmo",
     ".gop",
     ".graphics",
     ".gratis",
+    ".green",
     ".gripe",
     ".guide",
     ".guitars",
     ".guru",
+    ".hamburg",
     ".haus",
     ".hiphop",
+    ".hiv",
     ".holdings",
     ".holiday",
     ".homes",
     ".horse",
+    ".host",
     ".house",
     ".immobilien",
     ".industries",
@@ -129,15 +154,20 @@
     ".international",
     ".investments",
     ".jetzt",
+    ".joburg",
     ".juegos",
     ".kaufen",
     ".kim",
     ".kitchen",
     ".kiwi",
     ".koeln",
+    ".krd",
     ".kred",
+    ".lacaixa",
     ".land",
+    ".lawyer",
     ".lease",
+    ".lgbt",
     ".life",
     ".lighting",
     ".limited",
@@ -145,39 +175,55 @@
     ".link",
     ".loans",
     ".london",
+    ".lotto",
     ".luxe",
     ".luxury",
     ".maison",
     ".management",
     ".mango",
+    ".market",
     ".marketing",
     ".media",
     ".meet",
+    ".melbourne",
     ".menu",
     ".miami",
+    ".mini",
     ".moda",
     ".moe",
     ".monash",
+    ".mortgage",
     ".moscow",
     ".motorcycles",
     ".nagoya",
+    ".navy",
     ".net",
     ".neustar",
+    ".ngo",
+    ".nhk",
     ".ninja",
+    ".nra",
+    ".nrw",
     ".nyc",
     ".okinawa",
     ".onl",
     ".org",
+    ".organic",
+    ".ovh",
     ".paris",
     ".partners",
     ".parts",
     ".photo",
     ".photography",
     ".photos",
+    ".physio",
     ".pics",
     ".pictures",
     ".pink",
+    ".place",
     ".plumbing",
+    ".praxi",
+    ".press",
     ".productions",
     ".properties",
     ".pub",
@@ -185,12 +231,14 @@
     ".quebec",
     ".recipes",
     ".red",
+    ".rehab",
     ".reise",
     ".reisen",
     ".ren",
     ".rentals",
     ".repair",
     ".report",
+    ".republican",
     ".rest",
     ".reviews",
     ".rich",
@@ -200,27 +248,36 @@
     ".ruhr",
     ".ryukyu",
     ".saarland",
+    ".scb",
+    ".schmidt",
     ".schule",
+    ".scot",
     ".services",
     ".sexy",
     ".shiksha",
     ".shoes",
     ".singles",
     ".social",
+    ".software",
     ".sohu",
     ".solar",
     ".solutions",
     ".soy",
+    ".space",
+    ".spiegel",
     ".supplies",
     ".supply",
     ".support",
+    ".surf",
     ".surgery",
+    ".suzuki",
     ".systems",
     ".tattoo",
     ".tax",
     ".technology",
     ".tienda",
     ".tips",
+    ".tirol",
     ".today",
     ".tokyo",
     ".tools",
@@ -234,9 +291,11 @@
     ".vegas",
     ".ventures",
     ".versicherung",
+    ".vet",
     ".viajes",
     ".villas",
     ".vision",
+    ".vlaanderen",
     ".vodka",
     ".vote",
     ".voting",
@@ -245,7 +304,9 @@
     ".wang",
     ".watch",
     ".webcam",
+    ".website",
     ".wed",
+    ".whoswho",
     ".wien",
     ".wiki",
     ".works",
@@ -253,6 +314,7 @@
     ".wtf",
     ".xn--3bst00m",
     ".xn--3ds443g",
+    ".xn--4gbrim",
     ".xn--55qw42g",
     ".xn--55qx5d",
     ".xn--6frz82g",
@@ -269,6 +331,7 @@
     ".xn--fiq64b",
     ".xn--i1b6b1a6a2e",
     ".xn--io0a7i",
+    ".xn--kput3i",
     ".xn--mgbab2bd",
     ".xn--ngbc5azd",
     ".xn--nqv7f",
@@ -280,5 +343,6 @@
     ".xn--zfr164b",
     ".xyz",
     ".yachts",
+    ".yandex",
     ".yokohama",
     ".zone",
